@@ -209,12 +209,9 @@ free_filenames()
 void
 headerline(char *str)
 {
-	int i;
-
 	werase(top);
 	
-	for( i=0 ; i < COLS ; i++ )
-		mvwaddch(top, 1, i, '-');
+	mvwhline(top, 1, 0, ACS_HLINE, COLS);
 	
 	mvwprintw(top, 0, 0, "%s | %s", PACKAGE " " VERSION, str);
 
@@ -445,14 +442,10 @@ statusline_getnstr(char *str, int n, int use_filesel)
 void
 refresh_statusline()
 {
-	int i;
-	
 	werase(bottom);
 
-	for(i=0; i < COLS; i++) {
-		mvwaddch(bottom, 0, i, '-');
-		mvwaddch(bottom, 2, i, '-');
-	}
+	mvwhline(bottom, 0, 0, ACS_HLINE, COLS);
+	mvwhline(bottom, 2, 0, ACS_HLINE, COLS);
 
 	refresh();
 	wrefresh(bottom);
@@ -497,10 +490,19 @@ parse_command_line(int argc, char **argv)
 			mutt_query(argv[i + 1]);
 		else
 		if( !strcmp(argv[i], "--datafile") ) {
-			char *cwd = my_getcwd();
-			datafile = argv[i+1] ? strconcat(cwd, "/", argv[i + 1], NULL) : NULL;
-			free(cwd);
-			i++;
+			if (argv[i+1]) {
+				if (argv[i+1][0] != '/') {
+					char *cwd = my_getcwd();
+					datafile = strconcat(cwd, "/", argv[i+1], NULL);
+					free(cwd);
+				} else {
+					datafile = strdup(argv[i+1]);
+				}
+				i++;
+			} else {
+				show_usage();
+				exit(1);
+			}
 		} else
 		if( !strcmp(argv[i], "--convert") ) {
 			if( argc < 5 || argc > 6 ) {
@@ -603,7 +605,7 @@ init_mutt_query()
 	}
 }
 
-void
+static void
 quit_mutt_query()
 {
 	close_database();
