@@ -4,6 +4,9 @@
 /* Define if you have the <stdarg.h> header file.  */
 #undef HAVE_STDARG_H
 
+/* Define if you have the <ncurses.h> header file.  */
+#undef HAVE_NCURSES_H
+
 #undef HAVE_SNPRINTF
 #undef HAVE_VSNPRINTF
 
