@@ -28,6 +28,9 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
+#ifdef HAVE_CONFIG_H
+#	include "config.h"
+#endif
 #include "conff.h"
 
 #ifdef _AIX
