@@ -18,14 +18,9 @@
 #define WORKPHONE		8
 #define FAX			9
 #define MOBILEPHONE		10
-#if 0
 #define NICK			11
 #define URL			12
 #define NOTES			13
-#else
-#define URL                     11
-#define NOTES                   12
-#endif
 
 #define LAST_FIELD		NOTES
 
