@@ -9,6 +9,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 #include <pwd.h>
 #include <sys/types.h>
 #include "abook_curses.h"
@@ -29,6 +30,7 @@ extern struct abook_field abook_fields[];
  */
 
 static int      ldif_parse_file(FILE *handle);
+static int	mutt_parse_file(FILE *in);
 static int	pine_parse_file(FILE *in);
 
 static int      ldif_export_database(FILE *out);
@@ -45,6 +47,7 @@ static int	spruce_export_database(FILE *out);
 struct abook_filter i_filters[] = {
 	{ "abook", "abook native format", parse_database },
 	{ "ldif", "ldif / Netscape addressbook", ldif_parse_file },
+	{ "mutt", "mutt alias (beta)", mutt_parse_file },
 	{ "pine", "pine addressbook", pine_parse_file },
 	{ "\0", NULL, NULL }
 };
@@ -367,7 +370,7 @@ static void	ldif_fix_string(char *str);
 #	define LINESIZE 1024
 #endif
 
-#define	LDIF_ITEM_FIELDS	14
+#define	LDIF_ITEM_FIELDS	15
 
 typedef char*  ldif_item[LDIF_ITEM_FIELDS];
 
@@ -385,6 +388,7 @@ static ldif_item ldif_field_names = {
 	"facsimiletelephonenumber",
 	"cellphone",
 	"xmozillaanyphone",
+	"xmozillanickname",
 	"objectclass", /* this must be the last entry */
 };
 
@@ -402,6 +406,7 @@ static int ldif_conv_table[LDIF_ITEM_FIELDS] = {
 	FAX,		/* "facsimiletelephonenumber" */
 	MOBILEPHONE,	/* "cellphone" */
 	WORKPHONE,	/* "xmozillaanyphone" */
+	NICK,		/* "xmozillanickname" */
 	-1,             /* "objectclass" */ /* this must be the last entry */
 };
 
@@ -550,6 +555,142 @@ ldif_fix_string(char *str)
  * end of ldif import
  */
 
+/*
+ * mutt alias import filter
+ */
+
+#define MUTT_ALIAS	0
+#define MUTT_NAME	1
+#define MUTT_EMAIL	2
+
+static void
+remove_newlines(char *buf)
+{
+	int i,j;
+	
+	for(i=0,j=0; j < strlen(buf); i++, j++)
+		buf[i] = buf[j] == '\n' ? buf[++j] : buf[j];
+}
+
+static int
+mutt_read_line(FILE *in, char **alias, char **rest)
+{
+	char line[LINESIZE];
+	char *ptr=(char *)&line;
+	char *tmp;
+
+	fgets(line, LINESIZE, in);
+	remove_newlines(line);
+
+	while( isspace(*ptr) )
+		ptr++;
+
+	if( strncmp("alias", ptr, 5) ) {
+		return 1;
+	}
+		
+	ptr += 5;
+
+	while( isspace(*ptr) )
+		ptr++;
+
+	tmp = ptr;
+
+	while( ! isspace(*ptr) )
+		ptr++;
+
+	*alias = malloc(ptr-tmp+1);
+	strncpy(*alias, tmp, ptr-tmp);
+	*(*alias+(ptr-tmp)) = 0;
+
+	while( isspace(*ptr) )
+		ptr++;
+
+	*rest = strdup(ptr);	
+	
+	return 0;
+}
+
+static void
+mutt_parse_email(char *mutt_item[3])
+{
+	char *tmp;
+	int i;
+
+	if( (tmp = strchr(mutt_item[MUTT_NAME], '<')) )
+		*tmp = 0;
+	else
+		return;
+
+	mutt_item[MUTT_EMAIL] = strdup(tmp+1);
+
+	if( (tmp = strchr(mutt_item[MUTT_EMAIL], '>')) )
+		*tmp = 0;
+
+	tmp = mutt_item[MUTT_NAME];
+
+	for(i=strlen(tmp)-1; i>0; i--)
+		if(isspace(tmp[i]))
+			tmp[i] = 0;
+		else
+			break;
+
+	mutt_item[MUTT_NAME] = strdup(tmp);
+
+	free(tmp);
+}
+
+static void
+mutt_add_mutt_item(char *mutt_item[3])
+{
+	list_item abook_item;
+
+	memset(abook_item, 0, sizeof(abook_item));
+
+	abook_item[NAME] = safe_strdup(mutt_item[MUTT_NAME]);
+	abook_item[EMAIL] = safe_strdup(mutt_item[MUTT_EMAIL]);
+	abook_item[NICK] = safe_strdup(mutt_item[MUTT_ALIAS]);
+
+	add_item2database(abook_item);
+}
+
+static int
+mutt_parse_file(FILE *in)
+{
+	char *mutt_item[3];
+
+	for(;;) {
+
+		memset(mutt_item, 0, sizeof(mutt_item) );
+		
+		if( mutt_read_line(in, &mutt_item[MUTT_ALIAS],
+				&mutt_item[MUTT_NAME]) )
+			continue;
+
+		mutt_parse_email(mutt_item);
+
+		if( feof(in) ) {
+			free(mutt_item[MUTT_ALIAS]);
+			free(mutt_item[MUTT_NAME]);
+			free(mutt_item[MUTT_EMAIL]);
+			break;
+		}
+
+		mutt_add_mutt_item(mutt_item);
+
+		free(mutt_item[MUTT_ALIAS]);
+		free(mutt_item[MUTT_NAME]);
+		free(mutt_item[MUTT_EMAIL]);
+	}
+
+
+	return 0;
+}
+
+/*
+ * end of mutt alias import filter
+ */
+
 /*
  * ldif export filter
  */
@@ -711,8 +852,9 @@ pine_parse_buf(char *buf)
 	list_item item;
 	char *start = buf;
 	char *end;
-	char tmp[MAX_FIELD_LEN];
+	char tmp[400];
 	int i, len, last;
+	int pine_conv_table[]= {NICK, NAME, EMAIL, -1, NOTES};
 
 	memset(&item, 0, sizeof(item) );
 	
@@ -720,22 +862,14 @@ pine_parse_buf(char *buf)
 		if( ! (end = strchr(start, '\t')) )
 			last=1;
 		
-		len = last ? strlen(start) : min(MAX_FIELD_LEN - 1,
-				(int) (end-start) );
-		
-		switch( i ) {
-			case 1: strncpy(tmp, start, len);
-				tmp[len] = 0;
-				item[NAME] = strdup(tmp);
-				break;
-			case 2: strncpy(tmp, start, len);
-				tmp[len] = 0;
-				item[EMAIL] = strdup(tmp);
-				break;
-			case 4: strncpy(tmp, start, len);
-				tmp[len] = 0;
-				item[NOTES] = strdup(tmp);
-				break;
+		len = last ? strlen(start) : (int) (end-start);
+		len = min(len, 400-1);
+	
+		if(i < sizeof(pine_conv_table) / sizeof(*pine_conv_table)
+				&& pine_conv_table[i] >= 0) {
+			strncpy(tmp, start, len);
+			tmp[len] = 0;
+			item[pine_conv_table[i]] = strdup(tmp);
 		}
 		start = end + 1;
 	}
@@ -801,7 +935,8 @@ pine_export_database(FILE *out)
 
 	for(i=0; i < items; i++ ) {
 		fprintf(out, have_multiple_emails(i) ?
-				"\t%s\t(%s)\t\t%s\n" : "\t%s\t%s\t\t%s\n",
+				"%s\t%s\t(%s)\t\t%s\n" : "%s\t%s\t%s\t\t%s\n",
+				safe_str(database[i][NICK]),
 				safe_str(database[i][NAME]),
 				safe_str(database[i][EMAIL]),
 				safe_str(database[i][NOTES])
@@ -929,14 +1064,14 @@ gcrd_export_database(FILE *out)
  */
 
 static char *
-mutt_alias_genalias(char *str)
+mutt_alias_genalias(int i)
 {
 	char *tmp, *pos;
 	
-	if( !str )
-		return strdup("");
+	if(database[i][NICK])
+		return strdup(database[i][NICK]);
 
-	tmp = strdup(str);
+	tmp = strdup(database[i][NAME]);
 
 	if( ( pos = strchr(tmp, ' ') ) )
 		*pos = 0;
@@ -954,10 +1089,10 @@ mutt_alias_export(FILE *out)
 	char *alias = NULL;
 
 	for(i=0; i<items; i++) {
-		alias = mutt_alias_genalias(database[i][NAME]);
+		alias = mutt_alias_genalias(i);
+
 		get_first_email(email, i);
-		fprintf(out, "alias %d_%s %s <%s>\n",
-				i+1,
+		fprintf(out, *email ? "alias %s %s <%s>\n": "alias %s %s%s\n",
 				alias,
 				database[i][NAME],
 				email);
@@ -994,6 +1129,8 @@ text_export_database(FILE * out)
 		fprintf(out,
 			"-----------------------------------------\n\n");
 		fprintf(out, "%s", database[i][NAME]);
+		if (database[i][NICK])
+			fprintf(out, "\n(%s)", database[i][NICK]);
 		fprintf(out, "\n");
 
 		if (*database[i][EMAIL]) {
@@ -1085,10 +1222,9 @@ elm_alias_export(FILE *out)
 	char *alias = NULL;
 
 	for(i=0; i<items; i++) {
-		alias = mutt_alias_genalias(database[i][NAME]);
+		alias = mutt_alias_genalias(i);
 		get_first_email(email, i);
-		fprintf(out, "%d_%s = %s = %s\n",
-				i+1,
+		fprintf(out, "%s = %s = %s\n",
 				alias,
 				database[i][NAME],
 				email);
