@@ -85,6 +85,8 @@ print_list_line(int i, int line)
 {
 	char tmp[MAX_EMAILSTR_LEN];
 	int extra_column = options_get_int("list", "extra_column");
+	int real_emaillen = (extra_column > 2 && extra_column < ITEM_FIELDS) ?
+		EMAILLEN : EMAILPOS - COLS;
 
 	scrollok(list, FALSE);
 
@@ -93,10 +95,11 @@ print_list_line(int i, int line)
 	
 	mvwaddnstr(list, line, NAMEPOS, database[i][NAME], NAMELEN);
 	if( options_get_int( "list", "show_all_emails"  ) )
-		mvwaddnstr(list, line, EMAILPOS, database[i][EMAIL], EMAILLEN);
+		mvwaddnstr(list, line, EMAILPOS, database[i][EMAIL],
+				real_emaillen);
 	else {
 		get_first_email(tmp, i);
-		mvwaddnstr(list, line, EMAILPOS, tmp, EMAILLEN);
+		mvwaddnstr(list, line, EMAILPOS, tmp, real_emaillen);
 	}
 
 	if(extra_column > 2 && extra_column < ITEM_FIELDS)
