@@ -5,14 +5,12 @@
 void		init_list();
 void		close_list();
 void            refresh_list();
-void		refresh_curitem(int olditem);
 void		print_list_line(int i, int line);
 void		list_headerline();
 void            scroll_up();
 void            scroll_down();
 void		page_up();
 void		page_down();
-void		check_list();
 void            select_none();
 void            select_all();
 void            move_curitem(int direction);
