@@ -166,12 +166,8 @@ my_getcwd()
 
 	dir = malloc(size);
 	
-	for(;;) {
-		if( getcwd(dir, size) == NULL && errno == ERANGE )
-			dir = realloc(dir, size *= 2);
-		else
-			break;
-	}
+	while( getcwd(dir, size) == NULL && errno == ERANGE )
+		dir = realloc(dir, size *= 2);
 
 	return dir;
 }
