@@ -1,6 +1,9 @@
 #ifndef _OPTIONS_H
 #define _OPTIONS_H
 
+#define RCFILE		".abook.conf"
+#define SYSWIDE_RCFILE	"/etc/abook.conf"
+
 #include "conff.h"
 
 int	options_get_int(char *section, char *key);
